@@ -34,4 +34,11 @@ test_that("finding closest year works", {
     find_closest_year(as.Date("2022-12-31")),
     2023
   )
-})
\ No newline at end of file
+})
+
+test_that("list to vector works", {
+  expect_equal(
+    list_to_vector(list(1, 2, NA, NULL)),
+    c(1, 2, NA, NA)
+  )
+})
